Making a vase and a circular pattern suddenly starts acting weird 3/4 of the way around

daniel_wiseman
daniel_wiseman Member Posts: 7 ✭

Vases | Part Studio 2

So I was following a tutorial on creating vases for 3d printing and the work flow is to create your base shape, revolve a cylinder around it, put a helix on the cylinder, use the helix and one of the cylinder's base lines to create a spiraling surface (looks like an Archimedes screw with zero thickness) and then use an intersection curve to plot the spiral onto your base shape. Then loft a feature onto the surface using a sketch and the spiral curve we just mapped. This worked fantastically well for revolved objects and for MOST of this object but for some reason the circular pattern suddenly stops applying the loft as a feature to the base shape and starts making new parts entirely off to the side. I cannot understand what it's actually doing. Please take a look at my linked model to see where things are going haywire.

Screenshot 2025-05-05 150640.png

Answers

  • jelte_steur_info
    jelte_steur_info Member Posts: 683 PRO
    edited May 2025
  • jelte_steur_info
    jelte_steur_info Member Posts: 683 PRO
    edited May 2025

    so the intersection curves and sweep1 surface copies look alright, but sketch6 patterns are acting weirdly. somehow the constraint isn't determining the position of your circle correctly.

    Perhaps skip sketch6 and the regular sweep and use a custom wire feature instead? or profile sweep? to make the sweep?

    that'll make it a lot more robust. the end faces will not match the top faces. best would be to overbuild the whole vase and trim the end result flat.

    else replace-face the ends of the wires, but patterning that is a lot more computationally expensive.

  • romeograham
    romeograham Member, csevp Posts: 777 PRO

    Try using a pierce constraint between your circle sketch and the curve - that will keep your profile connected to the sweep path in each new location.

    Also - using Profile Sweeper (here) (as @jelte_steur814 mentioned) seems to reduce the rebuild from ~30s to ~9s, along with a single Boolean at the end to join everything, rather than Patterning the "add" function as part of the profile sweep.

    Romeo